@@ -17,6 +17,11 @@ class Syncthing:
         self._database = Database(self._api)
         self._events = Events(self._api)
 
+    @property
+    def url(self):
+        """Get URL."""
+        return self._api.url
+
     @property
     def system(self):
         """Get system api."""
