@@ -14,11 +14,7 @@ class System:
         """Check server availability."""
         try:
             result = await self._api.raw_request("rest/system/ping")
-            if (
-                not isinstance(result, dict)
-                or "ping" not in result
-                or result["ping"] != "pong"
-            ):
+            if not isinstance(result, dict) or "ping" not in result or result["ping"] != "pong":
                 raise PingError
         except Exception as error:
             raise PingError from error
@@ -38,21 +34,21 @@ class System:
     async def pause(self, device_id=None):
         """Pause synchronization."""
         try:
-            await self._api.request(
-                "rest/system/pause", method="POST", params=device_params(device_id)
-            )
+            await self._api.request("rest/system/pause", method="POST", params=device_params(device_id))
         except NotFoundError as error:
             raise UnknownDeviceError from error
 
     async def resume(self, device_id=None):
         """Resume synchronization."""
         try:
-            await self._api.request(
-                "rest/system/resume", method="POST", params=device_params(device_id)
-            )
+            await self._api.request("rest/system/resume", method="POST", params=device_params(device_id))
         except NotFoundError as error:
             raise UnknownDeviceError from error
 
+    async def connections(self):
+        """Get server connections."""
+        return await self._api.request("rest/system/connections")
+
 
 def device_params(device_id):
     """Build params hash from the device_id."""
